@@ -1,5 +1,5 @@
 ;; move-resize.jl -- interactive moving and resizing of windows
-;; $Id: move-resize.jl,v 1.82 2001/02/14 19:57:20 jsh Exp $
+;; $Id: move-resize.jl,v 1.83 2001/03/01 04:35:45 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -36,6 +36,7 @@
 	  sawfish.wm.commands
 	  sawfish.wm.custom
 	  sawfish.wm.events
+	  sawfish.wm.cursors
 	  sawfish.wm.util.stacking
 	  sawfish.wm.util.edges)
 
@@ -137,8 +138,8 @@
 			   (bottom-left-corner bottom left)
 			   (bottom-right-corner bottom right)))
 
-  (defvar move-cursor-shape 'hand2)
-  (defvar resize-cursor-shape 'hand2)
+  (defvar move-cursor-shape (default-cursor))
+  (defvar resize-cursor-shape (default-cursor))
 
   ;; specials, should make these fluids (external users?)
   (defvar move-resize-window nil)
