@@ -1,5 +1,5 @@
 ;; frames.jl -- handle window framing
-;; $Id: frames.jl,v 1.82 2001/01/27 02:36:40 jsh Exp $
+;; $Id: frames.jl,v 1.83 2001/03/01 04:35:44 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -582,8 +582,7 @@ deciding which frame type to ask a theme to generate.")
 	  ((top-left-corner) 'top_left_corner)
 	  ((top-right-corner) 'top_right_corner)
 	  ((bottom-left-corner) 'bottom_left_corner)
-	  ((bottom-right-corner) 'bottom_right_corner)
-	  ((title) 'hand2))
+	  ((bottom-right-corner) 'bottom_right_corner))
       nil))
 
 
