@@ -1,5 +1,5 @@
 ;; gnome.jl -- minimal GNOME compliance
-;; $Id: gnome.jl,v 1.68 2001/02/14 04:57:18 jsh Exp $
+;; $Id: gnome.jl,v 1.70 2001/03/06 19:55:19 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -294,6 +294,17 @@
 	   (set-window-depth w (- (aref data 0) WIN_LAYER_NORMAL))
 	   t)))
 
+  (define (gnome-property-handler w prop)
+    (when (windowp w)
+      (case prop
+	((_WIN_WORKSPACE)                       
+	  (let ((space (get-x-property w '_WIN_WORKSPACE)))
+	    (when (and space (eq (car space) 'CARDINAL))
+	      (let ((count (aref (nth 2 space) 0)))
+		(unless (window-appears-in-workspace-p
+			 w (workspace-id-from-logical count))
+		  (send-window-to-workspace-from-first w count)))))))))
+
   (define (gnome-event-proxyer)
     (when (and (current-event) (eq (current-event-window) 'root))
       (let ((event (event-name (current-event))))
@@ -374,6 +385,8 @@
     (call-after-state-changed '(window-list-skip) gnome-set-client-hints)
 
     (add-hook 'client-message-hook gnome-client-message-handler)
+    (add-hook 'property-notify-hook gnome-property-handler)
+
     (add-hook 'unbound-key-hook gnome-event-proxyer)
     (add-hook 'before-exit-hook gnome-exit))
 
