@@ -1,5 +1,5 @@
 ;; maximize.jl -- window maximization
-;; $Id: maximize.jl,v 1.55 2001/01/27 02:36:40 jsh Exp $
+;; $Id: maximize.jl,v 1.56 2001/03/06 19:55:19 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -545,7 +545,9 @@ unmaximized."
   (add-swapped-properties
    'unmaximized-geometry 'maximized-vertically 'maximized-horizontally)
 
-  (add-hook 'after-move-hook maximize-discard-move)
+  ;; This is now disabled - it doesn't really make sense for moving..
+  ;; (add-hook 'after-move-hook maximize-discard-move)
+
   (add-hook 'after-resize-hook maximize-discard-resize)
 
   (gaol-add window-maximized-p window-maximized-horizontally-p
