@@ -1,5 +1,5 @@
 ;; workspace.jl -- similar to virtual desktops
-;; $Id: workspace.jl,v 1.139 2000/10/27 00:31:08 jsh Exp $
+;; $Id: workspace.jl,v 1.145 2001/03/01 04:35:44 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -158,8 +158,9 @@
     :group workspace)
 
   (defcustom workspace-names nil
-    "Workspace names: \\w"
-    :type* `(list string ,(_ "Name"))
+    nil
+    :type* `(list string ,(_ "Workspace names"))
+    :widget-flags (expand-vertically)
     :group workspace)
 
   ;; Currently active workspace, an integer
@@ -814,7 +815,7 @@ previous workspace."
 			   current-workspace
 			 (car (window-workspaces w))))
 	   (new-space (workspace-id-from-logical count)))
-      (when orig-space
+      (when (and orig-space (/= orig-space new-space))
 	(copy-window-to-workspace w orig-space new-space was-focused)
 	(select-workspace new-space was-focused)
 	(unless copy
@@ -942,7 +943,7 @@ last instance remaining, then delete the actual window."
   (sm-add-saved-properties 'sticky 'iconified 'fixed-position)
 
   ;; some of these should really be added by other files
-  (add-swapped-properties 'frame-style 'type 'hide-client 'iconified)
+  (add-swapped-properties 'frame-style 'type 'iconified)
 
   (add-hook 'add-window-hook ws-add-window)
   (add-hook 'map-notify-hook ws-window-mapped)
