@@ -1,5 +1,5 @@
 /* display.c -- display handling
-   $Id: display.c,v 1.40 2000/09/17 12:28:05 john Exp $
+   $Id: display.c,v 1.41 2001/02/20 00:04:57 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -88,7 +88,7 @@ error_handler (Display *dpy, XErrorEvent *ev)
     if (w != 0)
     {
 	DB(("error_handler (%s)\n", rep_STR(w->name)));
-	if (w->id != 0)
+	if (!WINDOW_IS_GONE_P (w))
 	    remove_window (w, Qt, Qt);
 	/* so we call emit_pending_destroys () at some point */
 	rep_mark_input_pending (ConnectionNumber (dpy));
